==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/PolymorphicEventSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.NonLocalEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.PolymorphicEvent;
import io.ciera.tool.sql.ooaofooa.statemachine.PolymorphicEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.NonLocalEventSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventSetImpl;

import java.util.Arrays;
import java.util.List;


public class PolymorphicEventSetImpl extends InstanceSet<PolymorphicEventSet,PolymorphicEvent> implements PolymorphicEventSet {

    // attributes
    @Override
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException {
        for ( PolymorphicEvent polymorphicevent : this ) polymorphicevent.setSMspd_IDdeprecated( m_SMspd_IDdeprecated );
    }
    @Override
    public void setLocalClassName( String m_localClassName ) throws XtumlException {
        for ( PolymorphicEvent polymorphicevent : this ) polymorphicevent.setLocalClassName( m_localClassName );
    }
    @Override
    public void setLocalEventMning( String m_localEventMning ) throws XtumlException {
        for ( PolymorphicEvent polymorphicevent : this ) polymorphicevent.setLocalEventMning( m_localEventMning );
    }
    @Override
    public void setSMevt_ID( UniqueId ref_SMevt_ID ) throws XtumlException {
        for ( PolymorphicEvent polymorphicevent : this ) polymorphicevent.setSMevt_ID( ref_SMevt_ID );
    }
    @Override
    public void setLocalClassKL( String m_localClassKL ) throws XtumlException {
        for ( PolymorphicEvent polymorphicevent : this ) polymorphicevent.setLocalClassKL( m_localClassKL );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( PolymorphicEvent polymorphicevent : this ) polymorphicevent.setSM_ID( ref_SM_ID );
    }


    // selections
    @Override
    public StateMachineEventSet R525_is_a_StateMachineEvent() throws XtumlException {
        StateMachineEventSet statemachineeventset = new StateMachineEventSetImpl();
        for ( PolymorphicEvent polymorphicevent : this ) statemachineeventset.add( polymorphicevent.R525_is_a_StateMachineEvent() );
        return statemachineeventset;
    }
    @Override
    public NonLocalEventSet R527_is_aliased_by_NonLocalEvent() throws XtumlException {
        NonLocalEventSet nonlocaleventset = new NonLocalEventSetImpl();
        for ( PolymorphicEvent polymorphicevent : this ) nonlocaleventset.addAll( polymorphicevent.R527_is_aliased_by_NonLocalEvent() );
        return nonlocaleventset;
    }


    @Override
    public PolymorphicEvent nullElement() {
        return PolymorphicEventImpl.EMPTY_POLYMORPHICEVENT;
    }

    @Override
    public PolymorphicEventSet emptySet() {
      return new PolymorphicEventSetImpl();
    }

    @Override
    public PolymorphicEventSet value() {
        return this;
    }

    @Override
    public List<PolymorphicEvent> elements() {
        return Arrays.asList(toArray(new PolymorphicEvent[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/PolymorphicEventSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.NonLocalEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.PolymorphicEvent;
import io.ciera.tool.sql.ooaofooa.statemachine.PolymorphicEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.NonLocalEventSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class PolymorphicEventSetImpl extends InstanceSet<PolymorphicEventSet,PolymorphicEvent> implements PolymorphicEventSet {

    public PolymorphicEventSetImpl() {
    }

    public PolymorphicEventSetImpl(Comparator<? super PolymorphicEvent> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException {
        for ( PolymorphicEvent polymorphicevent : this ) polymorphicevent.setSMspd_IDdeprecated( m_SMspd_IDdeprecated );
    }
    @Override
    public void setLocalEventMning( String m_localEventMning ) throws XtumlException {
        for ( PolymorphicEvent polymorphicevent : this ) polymorphicevent.setLocalEventMning( m_localEventMning );
    }
    @Override
    public void setSMevt_ID( UniqueId ref_SMevt_ID ) throws XtumlException {
        for ( PolymorphicEvent polymorphicevent : this ) polymorphicevent.setSMevt_ID( ref_SMevt_ID );
    }
    @Override
    public void setLocalClassKL( String m_localClassKL ) throws XtumlException {
        for ( PolymorphicEvent polymorphicevent : this ) polymorphicevent.setLocalClassKL( m_localClassKL );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( PolymorphicEvent polymorphicevent : this ) polymorphicevent.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setLocalClassName( String m_localClassName ) throws XtumlException {
        for ( PolymorphicEvent polymorphicevent : this ) polymorphicevent.setLocalClassName( m_localClassName );
    }


    // selections
    @Override
    public StateMachineEventSet R525_is_a_StateMachineEvent() throws XtumlException {
        StateMachineEventSet statemachineeventset = new StateMachineEventSetImpl();
        for ( PolymorphicEvent polymorphicevent : this ) statemachineeventset.add( polymorphicevent.R525_is_a_StateMachineEvent() );
        return statemachineeventset;
    }
    @Override
    public NonLocalEventSet R527_is_aliased_by_NonLocalEvent() throws XtumlException {
        NonLocalEventSet nonlocaleventset = new NonLocalEventSetImpl();
        for ( PolymorphicEvent polymorphicevent : this ) nonlocaleventset.addAll( polymorphicevent.R527_is_aliased_by_NonLocalEvent() );
        return nonlocaleventset;
    }


    @Override
    public PolymorphicEvent nullElement() {
        return PolymorphicEventImpl.EMPTY_POLYMORPHICEVENT;
    }

    @Override
    public PolymorphicEventSet emptySet() {
      return new PolymorphicEventSetImpl();
    }

    @Override
    public PolymorphicEventSet emptySet(Comparator<? super PolymorphicEvent> comp) {
      return new PolymorphicEventSetImpl(comp);
    }

    @Override
    public PolymorphicEventSet value() {
        return this;
    }

    @Override
    public List<PolymorphicEvent> elements() {
        return Arrays.asList(toArray(new PolymorphicEvent[0]));
    }

}
